﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using Lib_MP_Communication;

namespace SDK_Sample
{
    public partial class frmMain : Form
    {
        // MP Device Communication Object
        public cls_MP_SDK g_objSDK;

        private frmGeneral_SetProtocol m_frmGeneral_SetProtocol = new frmGeneral_SetProtocol();
        private frmGeneral_AutoPolling m_frmGeneral_AutoPolling = new frmGeneral_AutoPolling();
        private frmISO14443A_GetUID m_frmISO14443A_GetUID = new frmISO14443A_GetUID();
        private frmMifare_ReadBlock m_frmMifare_Read = new frmMifare_ReadBlock();
        private frmMifare_WriteBlock m_frmMifare_Write = new frmMifare_WriteBlock();

        // When Data Recieved
        private void RX_Event(object sender, EventArgs e)
        {

            txtCommunicationLogs.Text = g_objSDK.CommunicationLogs;
            txtCommunicationLogs.Refresh();


        }

        // When Data Sent
        private void TX_Event(object sender, EventArgs e)
        {
            txtCommunicationLogs.Text = g_objSDK.CommunicationLogs;
        }

        //
        public frmMain()
        {
            InitializeComponent();

            g_objSDK = new cls_MP_SDK(spMain);

            g_objSDK.DataReceive += new EventHandler(RX_Event);
            g_objSDK.DataSent += new EventHandler(TX_Event);

            g_objSDK.RecordCommunicationLog = true;
        }

        // Setup Port Information
        private void m_vSetupPortInfo()
        {
            String[] strPortNames = System.IO.Ports.SerialPort.GetPortNames();

            // 
            mnuOpenPort.DropDownItems.Clear();

            mnuOpenPort.Text = "Open(" + strPortNames.Count().ToString() + ")";

            for (Int32 i32Lp = 0; i32Lp < strPortNames.Count(); i32Lp++)
            {
                mnuOpenPort.DropDownItems.Add(strPortNames[i32Lp]);
                mnuOpenPort.DropDownItems[mnuOpenPort.DropDownItems.Count - 1].Click += new System.EventHandler(m_vOpenPort); ;
            }
        }

        // Open Serial Port
        private void m_vOpenPort(object sender, EventArgs e)
        {
            ToolStripMenuItem objItem = (ToolStripMenuItem)sender;

            try
            {
                if (spMain.IsOpen == true) spMain.Close();
            }
            catch { }

            try
            {
                spMain.PortName = objItem.Text;
                spMain.Open();

                labStatus.Text = "Port:" + spMain.PortName + " ,Baudrate:" + spMain.BaudRate.ToString() + " ,Parity:" + spMain.Parity.ToString() + " ,Data bit:" + spMain.DataBits.ToString() + " ,Stop bit:" + spMain.StopBits.ToString();

                labStatus.Text += " ,HandShake:" + ((spMain.Handshake == System.IO.Ports.Handshake.None) ? "None" : "Hardware");

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }


        }

        //
        private void serialPortToolStripMenuItem_Click(object sender, EventArgs e)
        {
            m_vSetupPortInfo();
        }

        private void disconnectToolStripMenuItem_Click(object sender, EventArgs e)
        {
            g_objSDK.DisconnectToDeviceByUSB();

            labStatus.Text = "USB Disconnected";
        }

        private void connectToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Boolean bResult = g_objSDK.ConnectToDeviceByUSB();

            if (bResult == true)
                labStatus.Text = "USB Connected";
            else
                labStatus.Text = "USB Connect Fail";
        }

        private void trv_AfterSelect(object sender, TreeViewEventArgs e)
        {
            //String strItemName = ((ItemSelectArgs)e).strItemName;
            String strFullPath = e.Node.FullPath;

            // Clear Parameter Form
            g_Panel.Controls.Clear();

            // Clear Response Message
            txtResponse.Text = "";

            switch (strFullPath)
            {
                case "General\\Set Communication Protocol":
                    // Add Form to Panel
                    g_Panel.Controls.Add(m_frmGeneral_SetProtocol);
                    // Config Form Size
                    m_frmGeneral_SetProtocol.Size = g_Panel.Size;
                    // Assign Communication Object
                    m_frmGeneral_SetProtocol.m_objSDK = g_objSDK;
                    // Get Last Response Message
                    txtResponse.Text = m_frmGeneral_SetProtocol.strResponse;
                    // Config Response Message Object
                    m_frmGeneral_SetProtocol.m_txtResponse = txtResponse;
                    // Show Form
                    m_frmGeneral_SetProtocol.Show();
                    break;

                case "General\\Auto Polling":
                    // Add Form to Panel
                    g_Panel.Controls.Add(m_frmGeneral_AutoPolling);
                    // Config Form Size
                    m_frmGeneral_AutoPolling.Size = g_Panel.Size;
                    // Assign Communication Object
                    m_frmGeneral_AutoPolling.m_objSDK = g_objSDK;
                    // Get Last Response Message
                    txtResponse.Text = m_frmGeneral_AutoPolling.strResponse;
                    // Config Response Message Object
                    m_frmGeneral_AutoPolling.m_txtResponse = txtResponse;
                    // Show Form
                    m_frmGeneral_AutoPolling.Show();
                    break;

                case "ISO14443A\\Standard\\Get UID":
                    // Add Form to Panel
                    g_Panel.Controls.Add(m_frmISO14443A_GetUID);
                    // Config Form Size
                    m_frmISO14443A_GetUID.Size = g_Panel.Size;
                    // Assign Communication Object
                    m_frmISO14443A_GetUID.m_objSDK = g_objSDK;
                    // Get Last Response Message
                    txtResponse.Text = m_frmISO14443A_GetUID.strResponse;
                    // Config Response Message Object
                    m_frmISO14443A_GetUID.m_txtResponse = txtResponse;
                    // Show Form
                    m_frmISO14443A_GetUID.Show();
                    break;

                case "ISO14443A\\Mifare Classic\\Read Block":
                    // Add Form to Panel
                    g_Panel.Controls.Add(m_frmMifare_Read);
                    // Config Form Size
                    m_frmMifare_Read.Size = g_Panel.Size;
                    // Assign Communication Object
                    m_frmMifare_Read.m_objSDK = g_objSDK;
                    // Get Last Response Message
                    txtResponse.Text = m_frmMifare_Read.strResponse;
                    // Config Response Message Object
                    m_frmMifare_Read.m_txtResponse = txtResponse;
                    // Show Form
                    m_frmMifare_Read.Show();
                    break;

                case "ISO14443A\\Mifare Classic\\Write Block":
                    // Add Form to Panel
                    g_Panel.Controls.Add(m_frmMifare_Write);
                    // Config Form Size
                    m_frmMifare_Write.Size = g_Panel.Size;
                    // Assign Communication Object
                    m_frmMifare_Write.m_objSDK = g_objSDK;
                    // Get Last Response Message
                    txtResponse.Text = m_frmMifare_Write.strResponse;
                    // Config Response Message Object
                    m_frmMifare_Write.m_txtResponse = txtResponse;
                    // Show Form
                    m_frmMifare_Write.Show();
                    break;
            }
        }

        private void frmMain_FormClosing(object sender, FormClosingEventArgs e)
        {
            g_objSDK.Disconnect();

            g_objSDK.DisconnectToDeviceByUSB();
        }

    }
}
